@@ -105,6 +105,9 @@ check_PD <- function(vcov_list) {
 #' @export
 #'
 #' @examples
+#' 
+#' if (requireNamespace("metafor", quietly = TRUE)) {
+#' 
 #' library(metafor)
 #'
 #' # Constant correlation
@@ -113,6 +116,8 @@ check_PD <- function(vcov_list) {
 #' MVFE <- rma.mv(d ~ 0 + test, V = V_list, data = SATcoaching)
 #' conf_int(MVFE, vcov = "CR2", cluster = SATcoaching$study)
 #' 
+#' }
+#' 
 
 
 impute_covariance_matrix <- function(vi, cluster, r, ti, ar1, 
@@ -174,7 +179,7 @@ impute_covariance_matrix <- function(vi, cluster, r, ti, ar1,
   if (return_list) {
     return(vcov_list)
   } else {
-    vcov_mat <- metafor::bldiag(vcov_list)
+    vcov_mat <- unblock(vcov_list)
     cluster_index <- order(order(cluster))
     return(vcov_mat[cluster_index, cluster_index])
   }
@@ -234,10 +239,18 @@ impute_covariance_matrix <- function(vi, cluster, r, ti, ar1,
 #' @export
 #'
 #' @examples
+#' 
+#' pkgs_available <- 
+#'   requireNamespace("metafor", quietly = TRUE) & 
+#'   requireNamespace("robumeta", quietly = TRUE)
+#'   
+#' if (pkgs_available) {
 #' library(metafor)
 #'
 #' data(oswald2013, package = "robumeta")
 #' dat <- escalc(data = oswald2013, measure = "ZCOR", ri = R, ni = N)
+#' subset_ids <- unique(dat$Study)[1:20]
+#' dat <- subset(dat, Study %in% subset_ids)
 #' 
 #' # make a patterned correlation matrix 
 #' 
@@ -261,6 +274,8 @@ impute_covariance_matrix <- function(vi, cluster, r, ti, ar1,
 #'                
 #' conf_int(MVFE, vcov = "CR2")
 #' 
+#' }
+#' 
 
 
 pattern_covariance_matrix <- function(vi, cluster, pattern_level, r_pattern, r,
@@ -321,7 +336,7 @@ pattern_covariance_matrix <- function(vi, cluster, pattern_level, r_pattern, r,
   if (return_list) {
     return(vcov_list)
   } else {
-    vcov_mat <- metafor::bldiag(vcov_list)
+    vcov_mat <- unblock(vcov_list)
     cluster_index <- order(order(cluster))
     return(vcov_mat[cluster_index, cluster_index])
   }
@@ -356,20 +371,29 @@ pattern_covariance_matrix <- function(vi, cluster, pattern_level, r_pattern, r,
 #' @export
 #' 
 #' @examples
-#' library(metafor)
-#' data(hierdat, package = "robumeta")
 #' 
-#' mfor_fit <- rma.mv(effectsize ~ binge + followup + sreport + age, 
-#'                  V = var, random = list(~ 1 | esid, ~ 1 | studyid),
-#'                  data = hierdat)
+#' pkgs_available <- 
+#'   requireNamespace("metafor", quietly = TRUE) & 
+#'   requireNamespace("metadat", quietly = TRUE)
+#'
+#' if (pkgs_available) withAutoprint({
+#' 
+#' library(metafor)
+#' data(dat.assink2016, package = "metadat")
+#' 
+#' mfor_fit <- rma.mv(yi ~ year + deltype, 
+#'                  V = vi, random = ~ 1 | study / esid,
+#'                  data = dat.assink2016)
 #' mfor_fit
 #' 
 #' mfor_CR2 <- vcovCR(mfor_fit, type = "CR2")
 #' mfor_CR2
-#' coef_test(mfor_fit, vcov = mfor_CR2, test = c("Satterthwaite", "saddlepoint"))
 #' 
-#' Wald_test(mfor_fit, constraints = constrain_zero(c(2,4)), vcov = mfor_CR2)
-#' Wald_test(mfor_fit, constraints = constrain_zero(2:5), vcov = mfor_CR2)
+#' coef_test(mfor_fit, vcov = mfor_CR2, test = c("Satterthwaite", "saddlepoint"))
+#' Wald_test(mfor_fit, constraints = constrain_zero(3:4), vcov = mfor_CR2)
+#' 
+#' })
+#' 
 
 vcovCR.rma.mv <- function(obj, cluster, type, target, inverse_var, form = "sandwich", ...) {
   
@@ -411,7 +435,9 @@ vcovCR.rma.mv <- function(obj, cluster, type, target, inverse_var, form = "sandw
 #' @export
 
 targetVariance.rma.mv <- function(obj, cluster) {
-  matrix_list(obj$M, cluster, "both")
+  tV <- matrix_list(obj$M, cluster, "both")
+  if (!all(sapply(tV, is.matrix))) tV <- lapply(tV, as.matrix)
+  return(tV)
 }
 
 #-------------------------------------
@@ -423,10 +449,12 @@ targetVariance.rma.mv <- function(obj, cluster) {
 weightMatrix.rma.mv <- function(obj, cluster) {
   if (is.null(obj$W)) {
     V_list <- targetVariance(obj, cluster)
-    lapply(V_list, function(v) chol2inv(chol(v)))
+    Wm <- lapply(V_list, function(v) chol2inv(chol(v)))
   } else{
-    matrix_list(obj$W, cluster, "both")
+    Wm <- matrix_list(obj$W, cluster, "both")
+    if (!all(sapply(Wm, is.matrix))) Wm <- lapply(Wm, as.matrix)
   }
+  return(Wm)
 }
 
 #-----------------------------------------------
@@ -502,14 +530,20 @@ parse_structure <- function(obj) {
 #' @export
 #' 
 #' @examples
-#' library(metafor)
-#' data(hierdat, package = "robumeta")
 #' 
-#' mfor_fit <- rma.mv(effectsize ~ binge + followup + sreport + age, 
-#'                  V = var, random = list(~ 1 | esid, ~ 1 | studyid),
-#'                  data = hierdat)
+#' if (requireNamespace("metafor", quietly = TRUE)) {
+#' 
+#' library(metafor)
+#' data(dat.assink2016, package = "metadat")
+#' 
+#' mfor_fit <- rma.mv(yi ~ year + deltype, 
+#'                  V = vi, random = ~ 1 | study / esid,
+#'                  data = dat.assink2016)
+#'                  
 #' findCluster.rma.mv(mfor_fit)
 #' 
+#' }
+#' 
 
 findCluster.rma.mv <- function(obj) {
   
